@@ -8,7 +8,6 @@ class TestNodeWrite < Minitest::Test
   end
   
   def teardown
-    LibXML::XML.default_keep_blanks = true
     @doc = nil
   end
   
@@ -16,10 +15,8 @@ class TestNodeWrite < Minitest::Test
     @encoding = Encoding.find(name)
     @file_name = "model/bands.#{name.downcase}.xml"
 
-    # Strip spaces to make testing easier
-    LibXML::XML.default_keep_blanks = false
     file = File.join(File.dirname(__FILE__), @file_name)
-    @doc = LibXML::XML::Document.file(file)
+    @doc = LibXML::XML::Document.file(file, options: LibXML::XML::Parser::Options::NOBLANKS)
   end
 
   def test_to_s_default
